@@ -1,14 +1,14 @@
 var searchData=
 [
-  ['hadarmard_0',['hadarmard',['../classdsp_1_1Matrix.html#acc9b3f2466eadff9729f52cb2fa64cae',1,'dsp::Matrix::hadarmard(const Matrix &amp;a, const Matrix &amp;b)'],['../classdsp_1_1Matrix.html#ae81ba2ce83f715cd09aa696ae66cbca0',1,'dsp::Matrix::hadarmard(const Matrix &amp;other) noexcept']]],
+  ['hadarmard_0',['hadarmard',['../classjuce_1_1dsp_1_1Matrix.html#a2069bdc79d7b0810d9d7d8e6ec1adaad',1,'juce::dsp::Matrix::hadarmard(const Matrix &amp;other) noexcept'],['../classjuce_1_1dsp_1_1Matrix.html#a431293e2565c1e475b4d866a6fc67ded',1,'juce::dsp::Matrix::hadarmard(const Matrix &amp;a, const Matrix &amp;b)']]],
   ['haderror_1',['hadError',['../classURL_1_1DownloadTask.html#ad2e410697d4aba3a559700957ac93fa2',1,'URL::DownloadTask']]],
   ['handleaftertouch_2',['handleAftertouch',['../classSynthesiser.html#ae92ed64d170257574b9009b3384bde01',1,'Synthesiser']]],
-  ['handleasyncupdate_3',['handleAsyncUpdate',['../classModalComponentManager.html#a47d303fb64f3ae02deb986d58bfeb893',1,'ModalComponentManager::handleAsyncUpdate()'],['../classAsyncUpdater.html#a446f3af793131f8772329f1f8b526578',1,'AsyncUpdater::handleAsyncUpdate()'],['../classComboBox.html#a773b7375c6a370db67ed6fd16b4535a7',1,'ComboBox::handleAsyncUpdate()'],['../classMenuBarModel.html#a0dddd32a4b5bd42c1313751bb13f882e',1,'MenuBarModel::handleAsyncUpdate()']]],
+  ['handleasyncupdate_3',['handleAsyncUpdate',['../classAsyncUpdater.html#a446f3af793131f8772329f1f8b526578',1,'AsyncUpdater::handleAsyncUpdate()'],['../classModalComponentManager.html#a47d303fb64f3ae02deb986d58bfeb893',1,'ModalComponentManager::handleAsyncUpdate()'],['../classMenuBarModel.html#a0dddd32a4b5bd42c1313751bb13f882e',1,'MenuBarModel::handleAsyncUpdate()'],['../classComboBox.html#a773b7375c6a370db67ed6fd16b4535a7',1,'ComboBox::handleAsyncUpdate()']]],
   ['handlebroughttofront_4',['handleBroughtToFront',['../classComponentPeer.html#a8f451c2a22a1696443ab724fa62b9708',1,'ComponentPeer']]],
   ['handlecallbackinternal_5',['handleCallbackInternal',['../classAppleRemoteDevice.html#a016dfb4c500b9813c935f7387872d112',1,'AppleRemoteDevice']]],
   ['handlechannelpressure_6',['handleChannelPressure',['../classSynthesiser.html#aa1f2fdbce8a6502c52c70d34c3e52697',1,'Synthesiser']]],
   ['handlecommandmessage_7',['handleCommandMessage',['../classButton.html#a1d4d66619c1d44412892ab73ce806c8f',1,'Button::handleCommandMessage()'],['../classComponent.html#a9ba6fa31d1397c7e90050b2cd4f2089b',1,'Component::handleCommandMessage()'],['../classMenuBarComponent.html#ae5c5569ad0b47c72e234328f08326dff',1,'MenuBarComponent::handleCommandMessage()'],['../classCallOutBox.html#a14c430dd12c4a9dcd5549a37a70bd6c7',1,'CallOutBox::handleCommandMessage()']]],
-  ['handleconnectionlost_8',['handleConnectionLost',['../classChildProcessCoordinator.html#af2a8911a6dadd6a824de7cd11188a46a',1,'ChildProcessCoordinator::handleConnectionLost()'],['../classChildProcessWorker.html#a5e6b8194e9e34dbb5a80b558e12ddd9f',1,'ChildProcessWorker::handleConnectionLost()']]],
+  ['handleconnectionlost_8',['handleConnectionLost',['../classChildProcessWorker.html#a5e6b8194e9e34dbb5a80b558e12ddd9f',1,'ChildProcessWorker::handleConnectionLost()'],['../classChildProcessCoordinator.html#af2a8911a6dadd6a824de7cd11188a46a',1,'ChildProcessCoordinator::handleConnectionLost()']]],
   ['handleconnectionmade_9',['handleConnectionMade',['../classChildProcessWorker.html#a9820aa749fc27efa5d11a9cc219a9e06',1,'ChildProcessWorker']]],
   ['handlecontroller_10',['handleController',['../classMPESynthesiser.html#ae7e0785bd58e274b3ae7218bb468cb44',1,'MPESynthesiser::handleController()'],['../classSynthesiser.html#ae2dc8a91aff04f2e23b6ac22b4dd80a8',1,'Synthesiser::handleController()']]],
   ['handledragdrop_11',['handleDragDrop',['../classComponentPeer.html#a351c6a2ba20b0dfb55b3c11b7e5bfa9c',1,'ComponentPeer']]],
@@ -17,7 +17,7 @@ var searchData=
   ['handleescapekey_14',['handleEscapeKey',['../classCodeEditorComponent.html#a873ae3e9eb99f551754adc85ae738acb',1,'CodeEditorComponent']]],
   ['handlefocusgain_15',['handleFocusGain',['../classComponentPeer.html#a7f0f1bf14f3ad8df8372352804d1c54d',1,'ComponentPeer']]],
   ['handlefocusloss_16',['handleFocusLoss',['../classComponentPeer.html#a9d14cc3ce5afb95b4d8b62b90dbca46e',1,'ComponentPeer']]],
-  ['handleincomingmidimessage_17',['handleIncomingMidiMessage',['../classMidiMessageCollector.html#af76869b33248a78b2a580e63ec855773',1,'MidiMessageCollector::handleIncomingMidiMessage()'],['../classAudioProcessorPlayer.html#aa3f6a26339ac28951d252adf1b4a776e',1,'AudioProcessorPlayer::handleIncomingMidiMessage()'],['../classMidiInputCallback.html#acdf6d7e27b96a50fe06922737f0d082e',1,'MidiInputCallback::handleIncomingMidiMessage()']]],
+  ['handleincomingmidimessage_17',['handleIncomingMidiMessage',['../classMidiInputCallback.html#acdf6d7e27b96a50fe06922737f0d082e',1,'MidiInputCallback::handleIncomingMidiMessage()'],['../classMidiMessageCollector.html#af76869b33248a78b2a580e63ec855773',1,'MidiMessageCollector::handleIncomingMidiMessage()'],['../classAudioProcessorPlayer.html#aa3f6a26339ac28951d252adf1b4a776e',1,'AudioProcessorPlayer::handleIncomingMidiMessage()']]],
   ['handlekeypress_18',['handleKeyPress',['../classComponentPeer.html#ac03f1b3bf45aebeca5f45799b1647d59',1,'ComponentPeer::handleKeyPress(int keyCode, juce_wchar textCharacter)'],['../classComponentPeer.html#a6935e686c540ad229969695b57df7d7e',1,'ComponentPeer::handleKeyPress(const KeyPress &amp;key)']]],
   ['handlekeyupordown_19',['handleKeyUpOrDown',['../classComponentPeer.html#a100869544b69c072622bee3015202368',1,'ComponentPeer']]],
   ['handlemagnifygesture_20',['handleMagnifyGesture',['../classComponentPeer.html#ad13a929dc1da8052bb48d6eca2fa9c8e',1,'ComponentPeer']]],
@@ -33,8 +33,8 @@ var searchData=
   ['handlemouseevent_30',['handleMouseEvent',['../classComponentPeer.html#a744403dd1c8970e1ed742ee8d60c0011',1,'ComponentPeer']]],
   ['handlemousewheel_31',['handleMouseWheel',['../classComponentPeer.html#a9d8e4c4c9a151d697d0e5e06d0634756',1,'ComponentPeer']]],
   ['handlemovedorresized_32',['handleMovedOrResized',['../classComponentPeer.html#a8fb507144ba1144b75b63da1075807b9',1,'ComponentPeer']]],
-  ['handlenoteoff_33',['handleNoteOff',['../classMidiMessageCollector.html#a07e1a9bbeb9131dbe8d55431bb166ee8',1,'MidiMessageCollector::handleNoteOff()'],['../classMidiKeyboardState_1_1Listener.html#aedc74bd79578cb19edba66d38e9a93cf',1,'MidiKeyboardState::Listener::handleNoteOff()']]],
-  ['handlenoteon_34',['handleNoteOn',['../classMidiMessageCollector.html#a0e6368630ea8c456c79f86d8aebcaeb6',1,'MidiMessageCollector::handleNoteOn()'],['../classMidiKeyboardState_1_1Listener.html#a854381a64354389e0cb2c15ec1fb4b01',1,'MidiKeyboardState::Listener::handleNoteOn()']]],
+  ['handlenoteoff_33',['handleNoteOff',['../classMidiKeyboardState_1_1Listener.html#aedc74bd79578cb19edba66d38e9a93cf',1,'MidiKeyboardState::Listener::handleNoteOff()'],['../classMidiMessageCollector.html#a07e1a9bbeb9131dbe8d55431bb166ee8',1,'MidiMessageCollector::handleNoteOff()']]],
+  ['handlenoteon_34',['handleNoteOn',['../classMidiKeyboardState_1_1Listener.html#a854381a64354389e0cb2c15ec1fb4b01',1,'MidiKeyboardState::Listener::handleNoteOn()'],['../classMidiMessageCollector.html#a0e6368630ea8c456c79f86d8aebcaeb6',1,'MidiMessageCollector::handleNoteOn()']]],
   ['handlenotification_35',['handleNotification',['../structPushNotifications_1_1Listener.html#a36312f58ade7b38fd3167fe5a68376d2',1,'PushNotifications::Listener']]],
   ['handlenotificationaction_36',['handleNotificationAction',['../structPushNotifications_1_1Listener.html#a694cedbf97aef85f1f4d4885475324f7',1,'PushNotifications::Listener']]],
   ['handlepaint_37',['handlePaint',['../classComponentPeer.html#a360713977c8a8d38657247b16ff4e836',1,'ComponentPeer']]],
@@ -52,7 +52,7 @@ var searchData=
   ['handlevsthostcallbackavailable_49',['handleVstHostCallbackAvailable',['../structVST2ClientExtensions.html#abb3f392dcef1c5a8ed964d8ccce63e0f',1,'VST2ClientExtensions']]],
   ['handlevstmanufacturerspecific_50',['handleVstManufacturerSpecific',['../structVST2ClientExtensions.html#a21e4889dd6074b73f5a21bc7fa8fe3e9',1,'VST2ClientExtensions']]],
   ['handlevstplugincando_51',['handleVstPluginCanDo',['../structVST2ClientExtensions.html#a96d3d9a966b6b4b5b8370366dd05e84b',1,'VST2ClientExtensions']]],
-  ['hankel_52',['hankel',['../classdsp_1_1Matrix.html#aebd286b87365abfd3ccee493fb0532d1',1,'dsp::Matrix']]],
+  ['hankel_52',['hankel',['../classjuce_1_1dsp_1_1Matrix.html#ad7ab7c972048f015f54f29733bb39981',1,'juce::dsp::Matrix']]],
   ['has3dnow_53',['has3DNow',['../classSystemStats.html#a1879ae7e393b289d3f5a62f673bfc031',1,'SystemStats']]],
   ['hasabsolute_54',['hasAbsolute',['../structGridItem_1_1Property.html#af705c099a2035ec060564e30d6df33b4',1,'GridItem::Property']]],
   ['hasalphachannel_55',['hasAlphaChannel',['../classImage.html#abb862a4402074ef0dc0382e2c6267a32',1,'Image']]],
@@ -76,15 +76,15 @@ var searchData=
   ['haschangedsincesaved_73',['hasChangedSinceSaved',['../classFileBasedDocument.html#a5676fb4537c68957616bd24f54b58f22',1,'FileBasedDocument']]],
   ['haschangedsincesavepoint_74',['hasChangedSinceSavePoint',['../classCodeDocument.html#a4c3047eee0dad38555cf546c3ea3c15f',1,'CodeDocument']]],
   ['hascontrolpanel_75',['hasControlPanel',['../classAudioIODevice.html#ab85840f9ead545d0b3664d55158fd581',1,'AudioIODevice']]],
-  ['haseditor_76',['hasEditor',['../classAudioProcessorGraph.html#afdb5ca50f8d3ffef636be2b9dbdf08cf',1,'AudioProcessorGraph::hasEditor()'],['../classAudioProcessor.html#a00be8f595da09ba01d74cb7c52b8fb81',1,'AudioProcessor::hasEditor()'],['../classAudioProcessorGraph_1_1AudioGraphIOProcessor.html#aa0e5fd5f05d014cbb01c0bbfa651abdc',1,'AudioProcessorGraph::AudioGraphIOProcessor::hasEditor()']]],
+  ['haseditor_76',['hasEditor',['../classAudioProcessor.html#a00be8f595da09ba01d74cb7c52b8fb81',1,'AudioProcessor::hasEditor()'],['../classAudioProcessorGraph_1_1AudioGraphIOProcessor.html#aa0e5fd5f05d014cbb01c0bbfa651abdc',1,'AudioProcessorGraph::AudioGraphIOProcessor::hasEditor()'],['../classAudioProcessorGraph.html#afdb5ca50f8d3ffef636be2b9dbdf08cf',1,'AudioProcessorGraph::hasEditor()']]],
   ['hasfileextension_77',['hasFileExtension',['../classFile.html#a9a5b9f97e5e94aa43dd5df683543e1b1',1,'File']]],
   ['hasfma3_78',['hasFMA3',['../classSystemStats.html#a29437caec1936a765542ec3ec5e21cd1',1,'SystemStats']]],
   ['hasfma4_79',['hasFMA4',['../classSystemStats.html#af0867e25b93cb36f08552f84bc29b59f',1,'SystemStats']]],
   ['hasfocus_80',['hasFocus',['../classAccessibilityHandler.html#a0ccacf2fd854ed39a4988039dd573054',1,'AccessibilityHandler']]],
   ['hasfocusoutline_81',['hasFocusOutline',['../classComponent.html#a5c60b638b3e2e692df18e63c6f8857df',1,'Component']]],
-  ['hash_82',['hash',['../classString.html#a317bebf3259d5fefa6a2558b65ae2f77',1,'String::hash()'],['../classUuid.html#aaa9e337833ead2cb48039a09ddcd8106',1,'Uuid::hash()']]],
-  ['hashcode_83',['hashCode',['../classFile.html#ae5548575e6854b9837e5b42fc8df0e98',1,'File::hashCode()'],['../classString.html#ad8ca5cb11984df03ff9697442da5ae4b',1,'String::hashCode()'],['../classURLInputSource.html#a289bcfa8603911b61cd057ea0dd63646',1,'URLInputSource::hashCode()'],['../classFileInputSource.html#a95b676eefdd0f1b2978d9c31a6af5d10',1,'FileInputSource::hashCode()'],['../classAndroidDocumentInputSource.html#a385ea8cda7c0e56bd8b936c2da24a157',1,'AndroidDocumentInputSource::hashCode()'],['../classInputSource.html#a1fe754d44724da8eaef055c496ca4140',1,'InputSource::hashCode()']]],
-  ['hashcode64_84',['hashCode64',['../classString.html#ad71be66a9c181abae185b84f7cec5f17',1,'String::hashCode64()'],['../classFile.html#ad0075226638584f6fb30c0d515e182e9',1,'File::hashCode64()']]],
+  ['hash_82',['hash',['../classUuid.html#aaa9e337833ead2cb48039a09ddcd8106',1,'Uuid::hash()'],['../classString.html#a317bebf3259d5fefa6a2558b65ae2f77',1,'String::hash()']]],
+  ['hashcode_83',['hashCode',['../classFile.html#ae5548575e6854b9837e5b42fc8df0e98',1,'File::hashCode()'],['../classAndroidDocumentInputSource.html#a385ea8cda7c0e56bd8b936c2da24a157',1,'AndroidDocumentInputSource::hashCode()'],['../classFileInputSource.html#a95b676eefdd0f1b2978d9c31a6af5d10',1,'FileInputSource::hashCode()'],['../classInputSource.html#a1fe754d44724da8eaef055c496ca4140',1,'InputSource::hashCode()'],['../classURLInputSource.html#a289bcfa8603911b61cd057ea0dd63646',1,'URLInputSource::hashCode()'],['../classString.html#ad8ca5cb11984df03ff9697442da5ae4b',1,'String::hashCode()']]],
+  ['hashcode64_84',['hashCode64',['../classFile.html#ad0075226638584f6fb30c0d515e182e9',1,'File::hashCode64()'],['../classString.html#ad71be66a9c181abae185b84f7cec5f17',1,'String::hashCode64()']]],
   ['hashmap_85',['HashMap',['../classHashMap.html#a4d6d41cfc524ccc0a73f0251d7fc1fab',1,'HashMap']]],
   ['hasidenticalcontentto_86',['hasIdenticalContentTo',['../classFile.html#ad3170a56847a243b475a72ccc9968089',1,'File']]],
   ['haskeyboardfocus_87',['hasKeyboardFocus',['../classComponent.html#abf76cf5c3550c5c83bc585f86429b397',1,'Component']]],
@@ -95,43 +95,44 @@ var searchData=
   ['hasmovedsignificantlysincepressed_92',['hasMovedSignificantlySincePressed',['../classMouseInputSource.html#a50d0b35cef0fc91851c18e0c242f6adc',1,'MouseInputSource']]],
   ['hasname_93',['hasName',['../structGridItem_1_1Property.html#a7ef06fbb3b2ad9644c11b54d2ed6986d',1,'GridItem::Property']]],
   ['hasneon_94',['hasNeon',['../classSystemStats.html#a0e193b24d50ed44287099c8fbd879311',1,'SystemStats']]],
-  ['hasproperty_95',['hasProperty',['../classDynamicObject.html#a600910b3145a802f247b456f95b43e5f',1,'DynamicObject::hasProperty()'],['../classValueTree.html#a0dbec0d665fb9d57b9fd7b3189ec0ee0',1,'ValueTree::hasProperty()'],['../classvar.html#a1ac3c09cc21b32c4baa0f520c8783908',1,'var::hasProperty()']]],
+  ['hasproperty_95',['hasProperty',['../classDynamicObject.html#a600910b3145a802f247b456f95b43e5f',1,'DynamicObject::hasProperty()'],['../classvar.html#a1ac3c09cc21b32c4baa0f520c8783908',1,'var::hasProperty()'],['../classValueTree.html#a0dbec0d665fb9d57b9fd7b3189ec0ee0',1,'ValueTree::hasProperty()']]],
   ['hasreadaccess_96',['hasReadAccess',['../classFile.html#a9d46c7ee5e292e0a5d6720e979cf4a96',1,'File']]],
-  ['hassametypeas_97',['hasSameTypeAs',['../classvar.html#a6357525c383c7d52c43d1db7d0669f34',1,'var']]],
-  ['hasseparateinputsandoutputs_98',['hasSeparateInputsAndOutputs',['../classAudioIODeviceType.html#ac87c3129c8e55018e968225b4a47dc74',1,'AudioIODeviceType']]],
-  ['hasspan_99',['hasSpan',['../structGridItem_1_1Property.html#a1e9afac3f936a5a048b15ee2784d7a92',1,'GridItem::Property']]],
-  ['hassse_100',['hasSSE',['../classSystemStats.html#ad5f3b624e4b0d32db1c5702ee039a765',1,'SystemStats']]],
-  ['hassse2_101',['hasSSE2',['../classSystemStats.html#a55e24b924d9c64e019f1efe1888d2963',1,'SystemStats']]],
-  ['hassse3_102',['hasSSE3',['../classSystemStats.html#aa9ffa8da005c3311eda3ee34ecdd5b28',1,'SystemStats']]],
-  ['hassse41_103',['hasSSE41',['../classSystemStats.html#ab46b181da7ecf6c0f96e865b1a91e6f3',1,'SystemStats']]],
-  ['hassse42_104',['hasSSE42',['../classSystemStats.html#a1b3861b105869d8062a539142da7e741',1,'SystemStats']]],
-  ['hasssse3_105',['hasSSSE3',['../classSystemStats.html#afd53593c782c3770106954ace47ce25c',1,'SystemStats']]],
-  ['hasstopmessagebeensent_106',['hasStopMessageBeenSent',['../classMessageManager.html#a3b51c7c37417fea8c4f47ebb7913ddba',1,'MessageManager']]],
-  ['hasstreamfinished_107',['hasStreamFinished',['../classAudioTransportSource.html#a4914381d34ed8bff499ca878c2be83fb',1,'AudioTransportSource']]],
-  ['hastagname_108',['hasTagName',['../classXmlElement.html#ac50bc4ce0db92b84baf4baf1b9c4de1d',1,'XmlElement']]],
-  ['hastagnameignoringnamespace_109',['hasTagNameIgnoringNamespace',['../classXmlElement.html#abcf184f1ddfb5cbec32f20b9adefb4c7',1,'XmlElement']]],
-  ['hastype_110',['hasType',['../classValueTree.html#a5d41bc2066cae65b69aa614aa0f68ff1',1,'ValueTree']]],
-  ['hasvalue_111',['hasValue',['../classOptional.html#a526be66da8e92b60541e15593093bee3',1,'Optional::hasValue()'],['../classAndroidDocument.html#a40516a17b35a5125fb9cadc948eb4f8b',1,'AndroidDocument::hasValue()']]],
-  ['haswatchedcomponentbeendeleted_112',['hasWatchedComponentBeenDeleted',['../classPopupMenu_1_1Options.html#a6411ef9fb0d046aaa1c9b1e8c8a7e1e4',1,'PopupMenu::Options']]],
-  ['haswriteaccess_113',['hasWriteAccess',['../classFile.html#a5335004d1a8ec1673c616358adee00e7',1,'File']]],
-  ['heapblock_114',['HeapBlock',['../classHeapBlock.html#a7b5c4b5a56551744a36f68eefc27f6d7',1,'HeapBlock::HeapBlock(SizeType numElements)'],['../classHeapBlock.html#a6fa48a9a24fa7b9b84967c1c6aa29e24',1,'HeapBlock::HeapBlock(SizeType numElements, bool initialiseToZero)'],['../classHeapBlock.html#a43e44081c3cbef5f634dd5a2a58cd1bd',1,'HeapBlock::HeapBlock(HeapBlock &amp;&amp;other) noexcept'],['../classHeapBlock.html#a43360d0b67112a64db4c131cfe976a31',1,'HeapBlock::HeapBlock(HeapBlock&lt; OtherElementType, otherThrowOnFailure &gt; &amp;&amp;other) noexcept'],['../classHeapBlock.html#a720865797ff4f5e9e92432b0b231d110',1,'HeapBlock::HeapBlock()=default']]],
-  ['heavyweightleakedobjectdetector_115',['HeavyweightLeakedObjectDetector',['../classHeavyweightLeakedObjectDetector.html#ae84f4df4ce1826d3bf438bab330d2831',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector() noexcept'],['../classHeavyweightLeakedObjectDetector.html#a05a37f04096dfe2c59d654f87fb91c5f',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector(const HeavyweightLeakedObjectDetector &amp;) noexcept']]],
-  ['hexagonal_116',['hexagonal',['../classAudioChannelSet.html#a7ed53c9a23d40bd2dd50e1d7129837f8',1,'AudioChannelSet']]],
-  ['hide_117',['hide',['../classProcess.html#a01a7ddde215bcef03cd16587ed4b0a64',1,'Process']]],
-  ['hidecursor_118',['hideCursor',['../classMouseInputSource.html#a61bc07273b91b328bcff92e721a2461e',1,'MouseInputSource']]],
-  ['hideeditor_119',['hideEditor',['../classLabel.html#a6f5fd9653da51af4720d1ac5e54f18d8',1,'Label']]],
-  ['hideinfobubble_120',['hideInfoBubble',['../classSystemTrayIconComponent.html#ad9e5f01b380d85df60bc76dcb07baefc',1,'SystemTrayIconComponent']]],
-  ['hidepopup_121',['hidePopup',['../classComboBox.html#a68c3355b300f275af9962d772665fd53',1,'ComboBox']]],
-  ['hidetextbox_122',['hideTextBox',['../classSlider.html#a0780c7da80f4d487703e8247e92bea21',1,'Slider']]],
-  ['hidetip_123',['hideTip',['../classTooltipWindow.html#a917c164d878207aceb22a1c71a541731',1,'TooltipWindow']]],
-  ['hidewaitcursor_124',['hideWaitCursor',['../classMouseCursor.html#a4671d39f6abcc1ca73fd8d95cf1e4355',1,'MouseCursor']]],
-  ['highresolutiontickstoseconds_125',['highResolutionTicksToSeconds',['../classTime.html#a3c4d54513d5d2be78a790cfd0b8c0493',1,'Time']]],
-  ['highresolutiontimer_126',['HighResolutionTimer',['../classHighResolutionTimer.html#ac79eb2389b1d52cd4a387836fe9ce860',1,'HighResolutionTimer']]],
-  ['hirestimercallback_127',['hiResTimerCallback',['../classHighResolutionTimer.html#a38fac5960301220b28b687817e4e7598',1,'HighResolutionTimer']]],
-  ['hittest_128',['hitTest',['../classPositionedGlyph.html#a92491e5bb26267dfa36bb54fc0be7d0e',1,'PositionedGlyph::hitTest()'],['../classImageButton.html#a646b175c55ac588b8ffed117f213e8e2',1,'ImageButton::hitTest()'],['../classComponent.html#a2da9631236e1cbf1b340454209a6c9e0',1,'Component::hitTest()'],['../classDrawableImage.html#a0a6bd602f7d8dd85366b11b7419209ed',1,'DrawableImage::hitTest()'],['../classDrawableShape.html#ab5862ed42c7976a43791f56ae6173c27',1,'DrawableShape::hitTest()'],['../classResizableBorderComponent.html#acd797e21238848968eb9957106590253',1,'ResizableBorderComponent::hitTest()'],['../classResizableCornerComponent.html#acc3a046566ad8ab5aa5318b3a943d2fc',1,'ResizableCornerComponent::hitTest()'],['../classTabBarButton.html#ac6e24e3e9b5001e36a3014692257ea03',1,'TabBarButton::hitTest()'],['../classLassoComponent.html#ab67925a4436687bc41437c8460de710d',1,'LassoComponent::hitTest()'],['../classCallOutBox.html#a916cce375fb38ac4e77e4a8ef27591b6',1,'CallOutBox::hitTest()']]],
-  ['horizontal_129',['horizontal',['../classColourGradient.html#a95e4615b53d8c257903269522397f587',1,'ColourGradient::horizontal(Colour colour1, float x1, Colour colour2, float x2)'],['../classColourGradient.html#a62381b6286d9175e4e8451e9b4e5c035',1,'ColourGradient::horizontal(Colour colourLeft, Colour colourRight, Rectangle&lt; Type &gt; area)']]],
-  ['hostmidicontrollerisavailable_130',['hostMIDIControllerIsAvailable',['../classAudioProcessorEditor.html#a0e943df67341fbed55d08b93f6773170',1,'AudioProcessorEditor']]],
-  ['hours_131',['hours',['../classRelativeTime.html#a1ae421b15cbeb81220bbf544a116cb77',1,'RelativeTime']]],
-  ['hwndcomponent_132',['HWNDComponent',['../classHWNDComponent.html#a078cb399434604a7059c7f37813501ea',1,'HWNDComponent']]],
-  ['hyperlinkbutton_133',['HyperlinkButton',['../classHyperlinkButton.html#aab8c9244ad8e28df8d012bbb3fb5b89f',1,'HyperlinkButton::HyperlinkButton(const String &amp;linkText, const URL &amp;linkURL)'],['../classHyperlinkButton.html#a6248ace276d2aade28ae1c61f33e76fa',1,'HyperlinkButton::HyperlinkButton()']]]
+  ['hasrunningprocess_97',['hasRunningProcess',['../classChildProcessManager.html#a50dac2fb8db1aa5967c1c7bb7f4fca4c',1,'ChildProcessManager']]],
+  ['hassametypeas_98',['hasSameTypeAs',['../classvar.html#a6357525c383c7d52c43d1db7d0669f34',1,'var']]],
+  ['hasseparateinputsandoutputs_99',['hasSeparateInputsAndOutputs',['../classAudioIODeviceType.html#ac87c3129c8e55018e968225b4a47dc74',1,'AudioIODeviceType']]],
+  ['hasspan_100',['hasSpan',['../structGridItem_1_1Property.html#a1e9afac3f936a5a048b15ee2784d7a92',1,'GridItem::Property']]],
+  ['hassse_101',['hasSSE',['../classSystemStats.html#ad5f3b624e4b0d32db1c5702ee039a765',1,'SystemStats']]],
+  ['hassse2_102',['hasSSE2',['../classSystemStats.html#a55e24b924d9c64e019f1efe1888d2963',1,'SystemStats']]],
+  ['hassse3_103',['hasSSE3',['../classSystemStats.html#aa9ffa8da005c3311eda3ee34ecdd5b28',1,'SystemStats']]],
+  ['hassse41_104',['hasSSE41',['../classSystemStats.html#ab46b181da7ecf6c0f96e865b1a91e6f3',1,'SystemStats']]],
+  ['hassse42_105',['hasSSE42',['../classSystemStats.html#a1b3861b105869d8062a539142da7e741',1,'SystemStats']]],
+  ['hasssse3_106',['hasSSSE3',['../classSystemStats.html#afd53593c782c3770106954ace47ce25c',1,'SystemStats']]],
+  ['hasstopmessagebeensent_107',['hasStopMessageBeenSent',['../classMessageManager.html#a3b51c7c37417fea8c4f47ebb7913ddba',1,'MessageManager']]],
+  ['hasstreamfinished_108',['hasStreamFinished',['../classAudioTransportSource.html#a4914381d34ed8bff499ca878c2be83fb',1,'AudioTransportSource']]],
+  ['hastagname_109',['hasTagName',['../classXmlElement.html#ac50bc4ce0db92b84baf4baf1b9c4de1d',1,'XmlElement']]],
+  ['hastagnameignoringnamespace_110',['hasTagNameIgnoringNamespace',['../classXmlElement.html#abcf184f1ddfb5cbec32f20b9adefb4c7',1,'XmlElement']]],
+  ['hastype_111',['hasType',['../classValueTree.html#a5d41bc2066cae65b69aa614aa0f68ff1',1,'ValueTree']]],
+  ['hasvalue_112',['hasValue',['../classOptional.html#a526be66da8e92b60541e15593093bee3',1,'Optional::hasValue()'],['../classAndroidDocument.html#a40516a17b35a5125fb9cadc948eb4f8b',1,'AndroidDocument::hasValue()']]],
+  ['haswatchedcomponentbeendeleted_113',['hasWatchedComponentBeenDeleted',['../classPopupMenu_1_1Options.html#a6411ef9fb0d046aaa1c9b1e8c8a7e1e4',1,'PopupMenu::Options']]],
+  ['haswriteaccess_114',['hasWriteAccess',['../classFile.html#a5335004d1a8ec1673c616358adee00e7',1,'File']]],
+  ['heapblock_115',['HeapBlock',['../classHeapBlock.html#a720865797ff4f5e9e92432b0b231d110',1,'HeapBlock::HeapBlock()=default'],['../classHeapBlock.html#a7b5c4b5a56551744a36f68eefc27f6d7',1,'HeapBlock::HeapBlock(SizeType numElements)'],['../classHeapBlock.html#a6fa48a9a24fa7b9b84967c1c6aa29e24',1,'HeapBlock::HeapBlock(SizeType numElements, bool initialiseToZero)'],['../classHeapBlock.html#a43e44081c3cbef5f634dd5a2a58cd1bd',1,'HeapBlock::HeapBlock(HeapBlock &amp;&amp;other) noexcept'],['../classHeapBlock.html#a43360d0b67112a64db4c131cfe976a31',1,'HeapBlock::HeapBlock(HeapBlock&lt; OtherElementType, otherThrowOnFailure &gt; &amp;&amp;other) noexcept']]],
+  ['heavyweightleakedobjectdetector_116',['HeavyweightLeakedObjectDetector',['../classHeavyweightLeakedObjectDetector.html#ae84f4df4ce1826d3bf438bab330d2831',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector() noexcept'],['../classHeavyweightLeakedObjectDetector.html#a05a37f04096dfe2c59d654f87fb91c5f',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector(const HeavyweightLeakedObjectDetector &amp;) noexcept']]],
+  ['hexagonal_117',['hexagonal',['../classAudioChannelSet.html#a7ed53c9a23d40bd2dd50e1d7129837f8',1,'AudioChannelSet']]],
+  ['hide_118',['hide',['../classProcess.html#a01a7ddde215bcef03cd16587ed4b0a64',1,'Process']]],
+  ['hidecursor_119',['hideCursor',['../classMouseInputSource.html#a61bc07273b91b328bcff92e721a2461e',1,'MouseInputSource']]],
+  ['hideeditor_120',['hideEditor',['../classLabel.html#a6f5fd9653da51af4720d1ac5e54f18d8',1,'Label']]],
+  ['hideinfobubble_121',['hideInfoBubble',['../classSystemTrayIconComponent.html#ad9e5f01b380d85df60bc76dcb07baefc',1,'SystemTrayIconComponent']]],
+  ['hidepopup_122',['hidePopup',['../classComboBox.html#a68c3355b300f275af9962d772665fd53',1,'ComboBox']]],
+  ['hidetextbox_123',['hideTextBox',['../classSlider.html#a0780c7da80f4d487703e8247e92bea21',1,'Slider']]],
+  ['hidetip_124',['hideTip',['../classTooltipWindow.html#a917c164d878207aceb22a1c71a541731',1,'TooltipWindow']]],
+  ['hidewaitcursor_125',['hideWaitCursor',['../classMouseCursor.html#a4671d39f6abcc1ca73fd8d95cf1e4355',1,'MouseCursor']]],
+  ['highresolutiontickstoseconds_126',['highResolutionTicksToSeconds',['../classTime.html#a3c4d54513d5d2be78a790cfd0b8c0493',1,'Time']]],
+  ['highresolutiontimer_127',['HighResolutionTimer',['../classHighResolutionTimer.html#ac79eb2389b1d52cd4a387836fe9ce860',1,'HighResolutionTimer']]],
+  ['hirestimercallback_128',['hiResTimerCallback',['../classHighResolutionTimer.html#a38fac5960301220b28b687817e4e7598',1,'HighResolutionTimer']]],
+  ['hittest_129',['hitTest',['../classPositionedGlyph.html#a92491e5bb26267dfa36bb54fc0be7d0e',1,'PositionedGlyph::hitTest()'],['../classImageButton.html#a646b175c55ac588b8ffed117f213e8e2',1,'ImageButton::hitTest()'],['../classComponent.html#a2da9631236e1cbf1b340454209a6c9e0',1,'Component::hitTest()'],['../classDrawableImage.html#a0a6bd602f7d8dd85366b11b7419209ed',1,'DrawableImage::hitTest()'],['../classDrawableShape.html#ab5862ed42c7976a43791f56ae6173c27',1,'DrawableShape::hitTest()'],['../classResizableBorderComponent.html#acd797e21238848968eb9957106590253',1,'ResizableBorderComponent::hitTest()'],['../classResizableCornerComponent.html#acc3a046566ad8ab5aa5318b3a943d2fc',1,'ResizableCornerComponent::hitTest()'],['../classTabBarButton.html#ac6e24e3e9b5001e36a3014692257ea03',1,'TabBarButton::hitTest()'],['../classLassoComponent.html#ab67925a4436687bc41437c8460de710d',1,'LassoComponent::hitTest()'],['../classCallOutBox.html#a916cce375fb38ac4e77e4a8ef27591b6',1,'CallOutBox::hitTest()']]],
+  ['horizontal_130',['horizontal',['../classColourGradient.html#a95e4615b53d8c257903269522397f587',1,'ColourGradient::horizontal(Colour colour1, float x1, Colour colour2, float x2)'],['../classColourGradient.html#a62381b6286d9175e4e8451e9b4e5c035',1,'ColourGradient::horizontal(Colour colourLeft, Colour colourRight, Rectangle&lt; Type &gt; area)']]],
+  ['hostmidicontrollerisavailable_131',['hostMIDIControllerIsAvailable',['../classAudioProcessorEditor.html#a0e943df67341fbed55d08b93f6773170',1,'AudioProcessorEditor']]],
+  ['hours_132',['hours',['../classRelativeTime.html#a1ae421b15cbeb81220bbf544a116cb77',1,'RelativeTime']]],
+  ['hwndcomponent_133',['HWNDComponent',['../classHWNDComponent.html#a078cb399434604a7059c7f37813501ea',1,'HWNDComponent']]],
+  ['hyperlinkbutton_134',['HyperlinkButton',['../classHyperlinkButton.html#aab8c9244ad8e28df8d012bbb3fb5b89f',1,'HyperlinkButton::HyperlinkButton(const String &amp;linkText, const URL &amp;linkURL)'],['../classHyperlinkButton.html#a6248ace276d2aade28ae1c61f33e76fa',1,'HyperlinkButton::HyperlinkButton()']]]
 ];
